@@ -7,7 +7,7 @@ information.
 __author__ = "Michael Stephens <mstephens@sunlightfoundation.com>"
 __copyright__ = "Copyright (c) 2010 Sunlight Labs"
 __license__ = "BSD"
-__version__ = "0.3.1"
+__version__ = "0.3.2"
 
 from remoteobjects import RemoteObject, fields, ListObject
 import urllib
@@ -137,6 +137,7 @@ class Bill(OpenStateObject):
     sponsors = fields.List(fields.Object(Sponsor))
     votes = fields.List(fields.Object(Vote))
     versions = fields.List(fields.Object(Version))
+    alternate_titles = fields.List(fields.Field())
 
     @classmethod
     def get(cls, state, session, chamber, bill_id):
@@ -233,3 +234,37 @@ class Legislator(OpenStateObject):
 
     def __str__(self):
         return self.full_name
+
+
+class CommitteeMember(OpenStateObject):
+    leg_id = fields.Field()
+    role = fields.Field()
+    name = fields.Field('legislator')
+
+class Committee(OpenStateObject):
+    id = fields.Field()
+    state = fields.Field()
+    chamber = fields.Field()
+    committee = fields.Field()
+    subcommittee = fields.Field()
+    members = fields.List(fields.Object(CommitteeMember))
+
+    @classmethod
+    def get(cls, id):
+        """
+        Get a committee.
+
+        :param id: the committee's Open State ID (e.g. CAC000005)
+        """
+        func = 'committees/%s' % id
+        return super(Committee, cls).get(func)
+
+    @classmethod
+    def search(cls, **kwargs):
+        """
+        Search comittees.
+
+        Use keyword argmunents to filter by committee fields.
+        For example, ``openstates.Committee.search(state='ca')``.
+        """
+        return ListOf(cls).get('committees', kwargs).entries
